PDG Python API
==============

The Python package `pdg` provides programmatic access to the data
published by the  Particle Data Group (PDG) in the
*Review of Particle Physics*.

**PLEASE NOTE: This software is a beta release for testing and is still under active development.
The data provided by the present version should not be used in any scientific publications
without careful checking of every single data item retrieved from the PDG API.**

For documentation of the PDG API see https://pdgapi.lbl.gov/doc. 

The source code for this package can be found at
https://github.com/particledatagroup/api.

The *Review of Particle Physics* is available online from the PDG website at https://pdg.lbl.gov.

General information about PDG and the *Review of Particle Physics*
can be found at https://pdg.lbl.gov/about.

To provide feedback or report bugs, please contact api@pdg.lbl.gov.
